pub struct TestUpload { /* private fields */ }Trait Implementations
Sourceimpl Base for TestUpload
impl Base for TestUpload
Sourcefn new(
communication_line: Arc<MultiBus>,
shared_state: Arc<SharedState>,
) -> Self
fn new( communication_line: Arc<MultiBus>, shared_state: Arc<SharedState>, ) -> Self
Factory method for creating a new instance of the struct implementing the trait.
Sourcefn get_communication_line(&self) -> Arc<MultiBus> ⓘ
fn get_communication_line(&self) -> Arc<MultiBus> ⓘ
Returns a reference to the internal communication line (MultiBus). Read more
Returns a reference to the shared state storage. Read more
Sourcefn run_stream<'life0, 'async_trait>(
&'life0 self,
_src: String,
stream: Pin<Box<dyn Stream<Item = Bytes> + Send>>,
_file_name: String,
_lower_bound: usize,
) -> Pin<Box<dyn Future<Output = Result<String, Box<dyn Error + Send + Sync>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn run_stream<'life0, 'async_trait>(
&'life0 self,
_src: String,
stream: Pin<Box<dyn Stream<Item = Bytes> + Send>>,
_file_name: String,
_lower_bound: usize,
) -> Pin<Box<dyn Future<Output = Result<String, Box<dyn Error + Send + Sync>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Processes a readable stream, suitable for streaming data from a request. Read more
Sourcefn run<'life0, 'async_trait>(
&'life0 self,
_src: String,
_data: String,
) -> Pin<Box<dyn Future<Output = Result<String, Box<dyn Error + Send + Sync>>> + Send + 'async_trait>>where
Self: Sync + 'async_trait,
'life0: 'async_trait,
fn run<'life0, 'async_trait>(
&'life0 self,
_src: String,
_data: String,
) -> Pin<Box<dyn Future<Output = Result<String, Box<dyn Error + Send + Sync>>> + Send + 'async_trait>>where
Self: Sync + 'async_trait,
'life0: 'async_trait,
Asynchronously runs the handler logic, processing incoming data and using
the provided communication line. Read more
Sourcefn run_file<'life0, 'async_trait>(
&'life0 self,
_src: String,
_filename: String,
) -> Pin<Box<dyn Future<Output = Result<(Box<dyn AsyncRead + Send + Unpin>, u64), Box<dyn Error + Send + Sync>>> + Send + 'async_trait>>where
Self: Sync + 'async_trait,
'life0: 'async_trait,
fn run_file<'life0, 'async_trait>(
&'life0 self,
_src: String,
_filename: String,
) -> Pin<Box<dyn Future<Output = Result<(Box<dyn AsyncRead + Send + Unpin>, u64), Box<dyn Error + Send + Sync>>> + Send + 'async_trait>>where
Self: Sync + 'async_trait,
'life0: 'async_trait,
Processes a filename and returns a bytestream and its size. Read more
Sourcefn run_metadata<'life0, 'async_trait>(
&'life0 self,
_src: String,
_filename: String,
) -> Pin<Box<dyn Future<Output = Result<String, Box<dyn Error + Send + Sync>>> + Send + 'async_trait>>where
Self: Sync + 'async_trait,
'life0: 'async_trait,
fn run_metadata<'life0, 'async_trait>(
&'life0 self,
_src: String,
_filename: String,
) -> Pin<Box<dyn Future<Output = Result<String, Box<dyn Error + Send + Sync>>> + Send + 'async_trait>>where
Self: Sync + 'async_trait,
'life0: 'async_trait,
Returns metadata for a given file name. Read more
Sourcefn publish<'life0, 'async_trait>(
&'life0 self,
message: String,
to: String,
) -> Pin<Box<dyn Future<Output = String> + Send + 'async_trait>>where
Self: Sync + 'async_trait,
'life0: 'async_trait,
fn publish<'life0, 'async_trait>(
&'life0 self,
message: String,
to: String,
) -> Pin<Box<dyn Future<Output = String> + Send + 'async_trait>>where
Self: Sync + 'async_trait,
'life0: 'async_trait,
Publishes a message to a specific target via the communication line. Read more
Sourcefn dispatch<'life0, 'async_trait>(
&'life0 self,
message: String,
to: String,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
Self: Sync + 'async_trait,
'life0: 'async_trait,
fn dispatch<'life0, 'async_trait>(
&'life0 self,
message: String,
to: String,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
Self: Sync + 'async_trait,
'life0: 'async_trait,
Dispatches a message to a specific target without awaiting a response. Read more
Sourcefn publish_redis<'life0, 'async_trait>(
&'life0 self,
message: String,
to: String,
timeout: Option<u64>,
) -> Pin<Box<dyn Future<Output = String> + Send + 'async_trait>>where
Self: Sync + 'async_trait,
'life0: 'async_trait,
fn publish_redis<'life0, 'async_trait>(
&'life0 self,
message: String,
to: String,
timeout: Option<u64>,
) -> Pin<Box<dyn Future<Output = String> + Send + 'async_trait>>where
Self: Sync + 'async_trait,
'life0: 'async_trait,
Publishes a message to a Redis channel and waits for a response. Read more
Sourcefn dispatch_redis<'life0, 'async_trait>(
&'life0 self,
message: String,
to: String,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
Self: Sync + 'async_trait,
'life0: 'async_trait,
fn dispatch_redis<'life0, 'async_trait>(
&'life0 self,
message: String,
to: String,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
Self: Sync + 'async_trait,
'life0: 'async_trait,
Dispatches a message to a Redis channel without waiting for a response. Read more
Sourcefn subscribe_topic_redis<'life0, 'async_trait>(
&'life0 self,
topic: String,
) -> Pin<Box<dyn Future<Output = Result<RequestRedis, Box<dyn Error + Send + Sync>>> + Send + 'async_trait>>where
Self: Sync + 'async_trait,
'life0: 'async_trait,
fn subscribe_topic_redis<'life0, 'async_trait>(
&'life0 self,
topic: String,
) -> Pin<Box<dyn Future<Output = Result<RequestRedis, Box<dyn Error + Send + Sync>>> + Send + 'async_trait>>where
Self: Sync + 'async_trait,
'life0: 'async_trait,
Subscribes to a Redis topic and waits for the next message. Read more